==> pierogi_0.6.4.tar.gz: pierogi-0.6.4/keysets/dish.h <==
#ifndef DISH_H
#define DISH_H

#include "pirkeysetmetadata.h"

class QObject;

class DishReceiver1: public PIRKeysetMetaData
{
public:
  DishReceiver1(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1a: public DishReceiver1
{
public:
  DishReceiver1a(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1b: public DishReceiver1
{
public:
  DishReceiver1b(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1c: public DishReceiver1
{
public:
  DishReceiver1c(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1d: public DishReceiver1
{
public:
  DishReceiver1d(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1e: public DishReceiver1
{
public:
  DishReceiver1e(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1f: public DishReceiver1
{
public:
  DishReceiver1f(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1g: public DishReceiver1
{
public:
  DishReceiver1g(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1h: public DishReceiver1
{
public:
  DishReceiver1h(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1i: public DishReceiver1
{
public:
  DishReceiver1i(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1j: public DishReceiver1
{
public:
  DishReceiver1j(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1k: public DishReceiver1
{
public:
  DishReceiver1k(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1l: public DishReceiver1
{
public:
  DishReceiver1l(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1m: public DishReceiver1
{
public:
  DishReceiver1m(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1n: public DishReceiver1
{
public:
  DishReceiver1n(
    QObject *guiObject,
    unsigned int index);
};

class DishReceiver1o: public DishReceiver1
{
public:
  DishReceiver1o(
    QObject *guiObject,
    unsigned int index);
};

#endif // DISH_H

==> pierogi_1.0.0.tar.gz: pierogi-1.0.0/keysets/dish.h <==
#ifndef DISH_H
#define DISH_H

#include "pirkeysetmetadata.h"

class QObject;

class DishReceiver1: public PIRKeysetMetaData
{
public:
  DishReceiver1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1a: public DishReceiver1
{
public:
  DishReceiver1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1b: public DishReceiver1
{
public:
  DishReceiver1b(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1c: public DishReceiver1
{
public:
  DishReceiver1c(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1d: public DishReceiver1
{
public:
  DishReceiver1d(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1e: public DishReceiver1
{
public:
  DishReceiver1e(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1f: public DishReceiver1
{
public:
  DishReceiver1f(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1g: public DishReceiver1
{
public:
  DishReceiver1g(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1h: public DishReceiver1
{
public:
  DishReceiver1h(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1i: public DishReceiver1
{
public:
  DishReceiver1i(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1j: public DishReceiver1
{
public:
  DishReceiver1j(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1k: public DishReceiver1
{
public:
  DishReceiver1k(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1l: public DishReceiver1
{
public:
  DishReceiver1l(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1m: public DishReceiver1
{
public:
  DishReceiver1m(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1n: public DishReceiver1
{
public:
  DishReceiver1n(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class DishReceiver1o: public DishReceiver1
{
public:
  DishReceiver1o(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // DISH_H
